"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Allow = void 0;
const core_1 = require("@tsed/core");
const jsonEntityFn_1 = require("./jsonEntityFn");
const property_1 = require("./property");
/**
 * Add allowed values when the property or parameters is required.
 *
 * #### Example on parameter:
 *
 * ```typescript
 * @Post("/")
 * async method(@Allow("") @BodyParams("field") field: string) {}
 * ```
 * > Required will throw a BadRequest when the given value is `null` or `undefined` but not for an empty string.
 *
 * #### Example on model:
 *
 * ```typescript
 * class Model {
 *   @Allow("")
 *   field: string;
 * }
 * ```
 *
 * @returns {Function}
 * @decorator
 * @validation
 * @swagger
 * @schema
 * @input
 */
function Allow(...values) {
    const model = values.find((item) => (0, core_1.isClass)(item));
    return (0, core_1.useDecorators)(model && (0, property_1.Property)(model), (0, jsonEntityFn_1.JsonEntityFn)((store, args) => {
        store.schema.allow(...values);
        if (store.decoratorType === core_1.DecoratorTypes.PARAM) {
            store.required = true;
        }
        if (store.decoratorType === core_1.DecoratorTypes.PROP) {
            store.parentSchema.addRequired(store.propertyName);
        }
    }));
}
exports.Allow = Allow;
//# sourceMappingURL=allow.js.map